==> react-native-digitcamera-1.6.12.tgz: package/src/Screens/Consent.js <==
import {
  Alert,
  Image,
  StyleSheet,
  Text,
  View,
  KeyboardAvoidingView,
  BackHandler,
  Platform,
  FlatList,
} from "react-native";
import React, { useEffect, useRef, useState } from "react";
import Header from "../Screens/Header";
import { translate } from "react-native-digitcamera/src/common/localize/i18n";
import Orientation from "../../../react-native-orientation";
import { ScrollView } from "react-native-gesture-handler";
import Colors from "react-native-digitcamera/src/common/Colors";
import { PrimaryButton } from "../common/ThemedComponents";
import { SCREEN_HEIGHT } from "../../../../Components/common/Constants";
const camera_shutter = require("../../src/common/Image/camera_shutter.png");

const iOS = Platform.OS === "ios";
const ConsentData = [
  {
    icon: camera_shutter,
    name: "Camera",
  },
  {
    icon: camera_shutter,
    name: "Microphone",
  },
  {
    icon: camera_shutter,
    name: "Storage",
  },
  {
    icon: camera_shutter,
    name: "Location",
  },
  {
    icon: camera_shutter,
    name: "Proximity Sensor",
  },
  {
    icon: camera_shutter,
    name: "Screen Recording",
  },
];

const Consent = ({ navigation, route }) => {
  const [, updateState] = React.useState();
  const forceUpdate = React.useCallback(() => updateState({}), []);
  useEffect(() => {
    if (!iOS) {
      const Immersive = require("react-native-immersive").Immersive;
      Immersive.setImmersive(false);
    }
    Orientation.lockToPortrait();
  }, []);
  //to get activity id and activityTypeid

  const renderItem = ({ item, index }) => {
    return (
      <View style={{ flexDirection: "row", marginTop: 30 }}>
        <View style={styles.iconView}>
          <Image
            style={{ width: 21, height: 19, resizeMode: "center" }}
            source={item.icon}
          />
        </View>
        <View style={styles.nameView}>
          <Text style={styles.ConsentNameStyle}>{item.name}</Text>
        </View>
      </View>
    );
  };

  return (
    <KeyboardAvoidingView
      style={{ flex: 1, backgroundColor: Colors.white }}
      behavior={iOS ? "padding" : ""}
      enabled
    >
      <ScrollView
        style={{ flex: 1, backgroundColor: Colors.white }}
        keyboardShouldPersistTaps={iOS ? "always" : "handled"}
        keyboardDismissMode="on-drag"
      >
        <View style={styles.main}>
          <View style={styles.subView}>
            <Header
              showTitle={translate("Consent")}
              hideArrowBackButton={iOS ? true : false}
              onlanguagechange={() => {
                forceUpdate();
              }}
              onbackPress={() => {
                //call exit alert
                if (Platform.OS === "android") {
                  if (navigation.canGoBack()) {
                    navigation.pop();
                  } else {
                    if (Platform.OS === "android") {
                      Alert.alert(
                        translate("Close"),
                        translate("are you sure ?"),
                        [
                          {
                            text: translate("Yes"),
                            onPress: () => {
                              BackHandler.exitApp();
                            },
                            style: "cancel",
                          },
                          {
                            text: translate("No"),
                            onPress: () => {
                              console.log("on No pressed");
                            },
                          },
                        ]
                      );
                    }
                  }
                }
              }}
              isLogoutVisible={false}
            />
            {/* Title and subtitle */}
            <View style={styles.HeadingView}>
              <Text style={styles.headingText}>
                {translate("Need your consent to go ahead")}
              </Text>
              <Text style={styles.subText}>
                {translate(
                  "To ensure a smooth inspection experience, please give us access to your phone's:"
                )}
              </Text>
            </View>
            {/* Points */}
            <View style={styles.pointsView}>
              <FlatList
                data={ConsentData}
                keyExtractor={(item, index) => index.toString()}
                renderItem={renderItem}
                maxToRenderPerBatch={100}
                updateCellsBatchingPeriod={1000}
              />
              <Text style={[styles.subText, { marginTop: 36 }]}>
                {translate("Rest assured - your information is safe with us!")}
              </Text>
            </View>
            {/* Button */}
            <View style={styles.buttonView}>
              <PrimaryButton
                onPress={() => {
                  navigation.navigate("Toturial");
                }}
              >
                {translate("Let’s Begin")}
              </PrimaryButton>
            </View>
          </View>
        </View>
      </ScrollView>
    </KeyboardAvoidingView>
  );
};
export default Consent;

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: "flex-end",
  },
  main: {
    flex: 1,
    backgroundColor: "#FFFFFF",
  },
  imageView: {
    flex: 0.4,
    justifyContent: "center",
    alignItems: "center",
    marginTop: 50,
  },
  textView: {
    flex: 0.45,
  },
  buttonView: {
    flex: 0.15,
    flexDirection: "column",
    marginTop: "80%",
  },
  welcomeText: {
    fontSize: 18,
    fontFamily: "Muli-ExtraBold",
    marginBottom: 9,
    marginTop: 52,
  },
  subText: {
    fontFamily: "Mulish",
    fontSize: 16,
    marginTop: 8,
  },
  subView: {
    flex: 1,
    marginLeft: 16,
    marginRight: 16,
  },
  HeadingView: {
    flex: 0.2,
    marginTop: 36,
  },
  pointsView: {
    flex: 0.65,
  },
  headingText: {
    fontFamily: "Mulish",
    fontSize: 20,
  },
  iconView: {
    flex: 0.05,
  },
  nameView: {
    flex: 0.95,
  },
  ConsentNameStyle: {
    fontFamily: "Mulish",
    fontSize: 14,
  },
});

==> react-native-digitcamera-1.6.16.tgz: package/src/Screens/Consent.js <==
import {
  Alert,
  Image,
  StyleSheet,
  Text,
  View,
  KeyboardAvoidingView,
  BackHandler,
  Platform,
  FlatList,
} from "react-native";
import React, { useEffect, useRef, useState } from "react";
import Header from "../Screens/Header";
import { translate } from "react-native-digitcamera/src/common/localize/i18n";
import Orientation from "../../../react-native-orientation";
import { ScrollView } from "react-native-gesture-handler";
import Colors from "react-native-digitcamera/src/common/Colors";
import { PrimaryButton } from "../common/ThemedComponents";
import { SCREEN_HEIGHT } from "../../../../Components/common/Constants";
const camera_shutter = require("../../src/common/Image/camera_shutter.png");

const iOS = Platform.OS === "ios";
const ConsentData = [
  {
    icon: camera_shutter,
    name: "Camera",
  },
  {
    icon: camera_shutter,
    name: "Microphone",
  },
  {
    icon: camera_shutter,
    name: "Storage",
  },
  {
    icon: camera_shutter,
    name: "Location",
  },
  {
    icon: camera_shutter,
    name: "Proximity Sensor",
  },
  {
    icon: camera_shutter,
    name: "Screen Recording",
  },
];

const Consent = ({ navigation, route }) => {
  const [, updateState] = React.useState();
  const forceUpdate = React.useCallback(() => updateState({}), []);
  useEffect(() => {
    if (!iOS) {
      const Immersive = require("react-native-immersive").Immersive;
      Immersive.setImmersive(false);
    }
    Orientation.lockToPortrait();
  }, []);
  //to get activity id and activityTypeid

  const renderItem = ({ item, index }) => {
    return (
      <View style={{ flexDirection: "row", marginTop: 30 }}>
        <View style={styles.iconView}>
          <Image
            style={{ width: 21, height: 19, resizeMode: "center" }}
            source={item.icon}
          />
        </View>
        <View style={styles.nameView}>
          <Text style={styles.ConsentNameStyle}>{item.name}</Text>
        </View>
      </View>
    );
  };

  return (
    <KeyboardAvoidingView
      style={{ flex: 1, backgroundColor: Colors.white }}
      behavior={iOS ? "padding" : ""}
      enabled
    >
      <ScrollView
        style={{ flex: 1, backgroundColor: Colors.white }}
        keyboardShouldPersistTaps={iOS ? "always" : "handled"}
        keyboardDismissMode="on-drag"
      >
        <View style={styles.main}>
          <View style={styles.subView}>
            <Header
              showTitle={translate("Consent")}
              hideArrowBackButton={iOS ? true : false}
              onlanguagechange={() => {
                forceUpdate();
              }}
              onbackPress={() => {
                //call exit alert
                if (Platform.OS === "android") {
                  if (navigation.canGoBack()) {
                    navigation.pop();
                  } else {
                    if (Platform.OS === "android") {
                      Alert.alert(
                        translate("Close"),
                        translate("are you sure ?"),
                        [
                          {
                            text: translate("Yes"),
                            onPress: () => {
                              BackHandler.exitApp();
                            },
                            style: "cancel",
                          },
                          {
                            text: translate("No"),
                            onPress: () => {
                              console.log("on No pressed");
                            },
                          },
                        ]
                      );
                    }
                  }
                }
              }}
              isLogoutVisible={false}
            />
            {/* Title and subtitle */}
            <View style={styles.HeadingView}>
              <Text style={styles.headingText}>
                {translate("Need your consent to go ahead")}
              </Text>
              <Text style={styles.subText}>
                {translate(
                  "To ensure a smooth inspection experience, please give us access to your phone's:"
                )}
              </Text>
            </View>
            {/* Points */}
            <View style={styles.pointsView}>
              <FlatList
                data={ConsentData}
                keyExtractor={(item, index) => index.toString()}
                renderItem={renderItem}
                maxToRenderPerBatch={100}
                updateCellsBatchingPeriod={1000}
              />
              <Text style={[styles.subText, { marginTop: 36 }]}>
                {translate("Rest assured - your information is safe with us!")}
              </Text>
            </View>
            {/* Button */}
            <View style={styles.buttonView}>
              <PrimaryButton
                onPress={() => {
                  navigation.navigate("Toturial");
                }}
              >
                {translate("Let’s Begin")}
              </PrimaryButton>
            </View>
          </View>
        </View>
      </ScrollView>
    </KeyboardAvoidingView>
  );
};
export default Consent;

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: "flex-end",
  },
  main: {
    flex: 1,
    backgroundColor: "#FFFFFF",
  },
  imageView: {
    flex: 0.4,
    justifyContent: "center",
    alignItems: "center",
    marginTop: 50,
  },
  textView: {
    flex: 0.45,
  },
  buttonView: {
    flex: 0.15,
    flexDirection: "column",
    marginTop: "80%",
  },
  welcomeText: {
    fontSize: 18,
    fontFamily: "Muli-ExtraBold",
    marginBottom: 9,
    marginTop: 52,
  },
  subText: {
    fontFamily: "Muli-Regular",
    fontSize: 16,
    marginTop: 8,
  },
  subView: {
    flex: 1,
    marginLeft: 16,
    marginRight: 16,
  },
  HeadingView: {
    flex: 0.2,
    marginTop: 36,
  },
  pointsView: {
    flex: 0.65,
  },
  headingText: {
    fontFamily: "Muli-Regular",
    fontSize: 20,
  },
  iconView: {
    flex: 0.05,
  },
  nameView: {
    flex: 0.95,
  },
  ConsentNameStyle: {
    fontFamily: "Muli-Regular",
    fontSize: 14,
  },
});
